aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--discord/client.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/discord/client.py b/discord/client.py
index 707e07b6..33491165 100644
--- a/discord/client.py
+++ b/discord/client.py
@@ -478,7 +478,7 @@ class Client:
# listeners/waiters
@asyncio.coroutine
- def wait_for_ready(self):
+ def wait_until_ready(self):
"""|coro|
This coroutine waits until the client is all ready. This could be considered
@@ -488,12 +488,12 @@ class Client:
yield from self._is_ready.wait()
@asyncio.coroutine
- def wait_for_login(self):
+ def wait_until_login(self):
"""|coro|
This coroutine waits until the client is logged on successfully. This
is different from waiting until the client's state is all ready. For
that check :func:`discord.on_ready` and :meth:`wait_for_ready`.
"""
yield from self._is_logged_in.wait()
@@ -488,12 +488,12 @@ class Client:
This coroutine waits until the client is logged on successfully. This
is different from waiting until the client's state is all ready. For
- that check :func:`discord.on_ready` and :meth:`wait_for_ready`.
+ that check :func:`discord.on_ready` and :meth:`wait_until_ready`.
"""
yield from self._is_logged_in.wait()